==> metawidget-all-1.30-sources.jar: org/metawidget/inspector/faces/UiFacesComponent.java <==
// Metawidget
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

package org.metawidget.inspector.faces;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotates the field should be rendered using the given Faces <code>UIComponent</code> in the UI.
 * <p>
 * Use of this annotation does not bind the business class to the UI quite as tightly as it may
 * appear, because JSF has a loosely coupled relationship between
 * <code>&lt;component-name&gt;</code> and <code>&lt;component-class&gt;</code>, and a further loose
 * coupling between <code>&lt;component&gt;</code> and <code>&lt;render-kit&gt;</code> - as defined
 * in <code>faces-config.xml</code>.
 *
 * @author Richard Kennard
 */

@Retention( RetentionPolicy.RUNTIME )
@Target( { ElementType.FIELD, ElementType.METHOD } )
public @interface UiFacesComponent {

	String value();
}

==> metawidget-all-3.1-sources.jar: org/metawidget/inspector/faces/UiFacesComponent.java <==
// Metawidget
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

package org.metawidget.inspector.faces;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotates the field should be rendered using the given Faces <em>component type</em> in the UI.
 * <p>
 * Use of this annotation does not bind the business class to the UI quite as tightly as it may
 * appear, because JSF has a loosely coupled relationship between
 * <code>&lt;component-type&gt;</code> and <code>&lt;component-class&gt;</code>, and a further loose
 * coupling between <code>&lt;component&gt;</code> and <code>&lt;render-kit&gt;</code> - as defined
 * in <code>faces-config.xml</code>.
 *
 * @author Richard Kennard
 */

@Retention( RetentionPolicy.RUNTIME )
@Target( { ElementType.FIELD, ElementType.METHOD } )
public @interface UiFacesComponent {

	String value();
}
